@@ -1,15 +1,20 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+"""
+Information on specific functions, classes, and methods.
+
+:Release: |version|
+:Date: |today|
+
+Top-level module API
+--------------------
+
+"""
 import os
 from distutils.version import LooseVersion
 
-from .info import (
-    LONG_DESCRIPTION as __doc__,
-    URL as __url__,
-    STATUS as __status__,
-    __version__,
-)
+from .info import URL as __url__, STATUS as __status__, __version__
 from .utils.config import NipypeConfig
 from .utils.logger import Logging
 from .refs import due
@@ -67,10 +72,12 @@ from .interfaces import (
 
 
 def check_latest_version(raise_exception=False):
-    """Check for the latest version of the library
+    """
+    Check for the latest version of the library.
 
-    parameters:
-    raise_exception: boolean
+    Parameters
+    ----------
+    raise_exception: bool
         Raise a RuntimeError if a bad version is being used
     """
     import etelemetry
@@ -94,6 +101,8 @@ def check_latest_version(raise_exception=False):
                         packname="nipype", version=__version__, latest=latest["version"]
                     )
                 )
+            else:
+                logger.info("No new version available.")
             if latest["bad_versions"] and any(
                 [
                     LooseVersion(__version__) == LooseVersion(ver)
@@ -115,7 +124,7 @@ def check_latest_version(raise_exception=False):
 if config.getboolean("execution", "check_version"):
     import __main__
 
-    if not hasattr(__main__, "__file__"):
+    if not hasattr(__main__, "__file__") and "NIPYPE_NO_ET" not in os.environ:
         from .interfaces.base import BaseInterface
 
         if BaseInterface._etelemetry_version_data is None:
