@@ -87,7 +87,7 @@ class ANTSInputSpec(ANTSCommandInputSpec):
         desc="",
     )
     gradient_step_length = traits.Float(requires=["transformation_model"], desc="")
-    number_of_time_steps = traits.Float(requires=["gradient_step_length"], desc="")
+    number_of_time_steps = traits.Int(requires=["gradient_step_length"], desc="")
     delta_time = traits.Float(requires=["number_of_time_steps"], desc="")
     symmetry_type = traits.Float(requires=["delta_time"], desc="")
 
@@ -1653,15 +1653,18 @@ class RegistrationSynQuickInputSpec(ANTSCommandInputSpec):
         "b",
         "br",
         argstr="-t %s",
-        desc="""
-                                 transform type
-                                 t:  translation
-                                 r:  rigid
-                                 a:  rigid + affine
-                                 s:  rigid + affine + deformable syn (default)
-                                 sr: rigid + deformable syn
-                                 b:  rigid + affine + deformable b-spline syn
-                                 br: rigid + deformable b-spline syn""",
+        desc="""\
+Transform type
+
+  * t:  translation
+  * r:  rigid
+  * a:  rigid + affine
+  * s:  rigid + affine + deformable syn (default)
+  * sr: rigid + deformable syn
+  * b:  rigid + affine + deformable b-spline syn
+  * br: rigid + deformable b-spline syn
+
+""",
         usedefault=True,
     )
 
