@@ -904,7 +904,7 @@ class Eddy(FSLCommand):
     """
     Interface for FSL eddy, a tool for estimating and correcting eddy
     currents induced distortions. `User guide
-    <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/eddy/UsersGuide>`_ and
+    <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/eddy/UsersGuide>`__ and
     `more info regarding acqp file
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/eddy/Faq#How_do_I_know_what_to_put_into_my_--acqp_file.3F>`_.
 
@@ -1418,7 +1418,7 @@ class EPIDeWarp(FSLCommand):
         warnings.warn(
             (
                 "Deprecated: Please use "
-                "nipype.workflows.dmri.preprocess.epi.sdc_fmb instead"
+                "niflow.nipype1.workflows.dmri.preprocess.epi.sdc_fmb instead"
             ),
             DeprecationWarning,
         )
@@ -1648,7 +1648,7 @@ class EddyQuad(FSLCommand):
     """
     Interface for FSL eddy_quad, a tool for generating single subject reports
     and storing the quality assessment indices for each subject.
-    `User guide <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/eddyqc/UsersGuide>`_
+    `User guide <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/eddyqc/UsersGuide>`__
 
     Examples
     --------
