@@ -14,10 +14,6 @@ you can test by calling::
 
    spm.SPMCommand().version
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-from builtins import range, object, str, bytes
-
 # Standard library imports
 import os
 from copy import deepcopy
@@ -29,15 +25,23 @@ import numpy as np
 # Local imports
 from ... import logging
 from ...utils import spm_docs as sd, NUMPY_MMAP
-from ..base import (BaseInterface, traits, isdefined, InputMultiPath,
-                    BaseInterfaceInputSpec, Directory, Undefined, ImageFile,
-                    PackageInfo)
+from ..base import (
+    BaseInterface,
+    traits,
+    isdefined,
+    InputMultiPath,
+    BaseInterfaceInputSpec,
+    Directory,
+    Undefined,
+    ImageFile,
+    PackageInfo,
+)
 from ..base.traits_extension import NoDefaultSpecified
 from ..matlab import MatlabCommand
 from ...external.due import due, Doi, BibTeX
 
-__docformat__ = 'restructuredtext'
-logger = logging.getLogger('nipype.interface')
+__docformat__ = "restructuredtext"
+logger = logging.getLogger("nipype.interface")
 
 
 def func_is_3d(in_file):
@@ -70,18 +74,18 @@ def scans_for_fname(fname):
 
     """
     if isinstance(fname, list):
-        scans = np.zeros((len(fname), ), dtype=object)
+        scans = np.zeros((len(fname),), dtype=object)
         for sno, f in enumerate(fname):
-            scans[sno] = '%s,1' % f
+            scans[sno] = "%s,1" % f
         return scans
     img = load(fname, mmap=NUMPY_MMAP)
     if len(img.shape) == 3:
-        return np.array(('%s,1' % fname, ), dtype=object)
+        return np.array(("%s,1" % fname,), dtype=object)
     else:
         n_scans = img.shape[3]
-        scans = np.zeros((n_scans, ), dtype=object)
+        scans = np.zeros((n_scans,), dtype=object)
         for sno in range(n_scans):
-            scans[sno] = '%s,%d' % (fname, sno + 1)
+            scans[sno] = "%s,%d" % (fname, sno + 1)
         return scans
 
 
@@ -102,7 +106,7 @@ def scans_for_fnames(fnames, keep4d=False, separate_sessions=False):
         if func_is_3d(fnames[0]):
             fnames = [fnames]
     if separate_sessions or keep4d:
-        flist = np.zeros((len(fnames), ), dtype=object)
+        flist = np.zeros((len(fnames),), dtype=object)
     for i, f in enumerate(fnames):
         if separate_sessions:
             if keep4d:
@@ -132,6 +136,7 @@ class Info(PackageInfo):
     to any call in the Info class to maintain memoization. Otherwise, it will
     default to the parameters in the `getinfo` function below.
     """
+
     _path = None
     _name = None
     _command = None
@@ -183,19 +188,22 @@ class Info(PackageInfo):
             returns None of path not found
         """
 
-        use_mcr = use_mcr or 'FORCE_SPMMCR' in os.environ
-        matlab_cmd = matlab_cmd or ((use_mcr and os.getenv('SPMMCRCMD'))
-                      or os.getenv('MATLABCMD', 'matlab -nodesktop -nosplash'))
+        use_mcr = use_mcr or "FORCE_SPMMCR" in os.environ
+        matlab_cmd = matlab_cmd or (
+            (use_mcr and os.getenv("SPMMCRCMD"))
+            or os.getenv("MATLABCMD", "matlab -nodesktop -nosplash")
+        )
 
-        if klass._name and klass._path and klass._version and \
-                klass._command == matlab_cmd and klass._paths == paths:
+        if (
+            klass._name
+            and klass._path
+            and klass._version
+            and klass._command == matlab_cmd
+            and klass._paths == paths
+        ):
 
-            return {
-                'name': klass._name,
-                'path': klass._path,
-                'release': klass._version
-            }
-        logger.debug('matlab command or path has changed. recomputing version.')
+            return {"name": klass._name, "path": klass._path, "release": klass._version}
+        logger.debug("matlab command or path has changed. recomputing version.")
         mlab = MatlabCommand(matlab_cmd=matlab_cmd, resource_monitor=False)
         mlab.inputs.mfile = False
         if paths:
@@ -220,7 +228,7 @@ exit;
         except (IOError, RuntimeError) as e:
             # if no Matlab at all -- exception could be raised
             # No Matlab -- no spm
-            logger.debug('%s', e)
+            logger.debug("%s", e)
             klass._version = None
             klass._path = None
             klass._name = None
@@ -230,13 +238,13 @@ exit;
 
         out = sd._strip_header(out.runtime.stdout)
         out_dict = {}
-        for part in out.split('|'):
-            key, val = part.split(':')
+        for part in out.split("|"):
+            key, val = part.split(":")
             out_dict[key] = val
 
-        klass._version = out_dict['release']
-        klass._path = out_dict['path']
-        klass._name = out_dict['name']
+        klass._version = out_dict["release"]
+        klass._path = out_dict["path"]
+        klass._name = out_dict["name"]
         klass._command = matlab_cmd
         klass._paths = paths
         return out_dict
@@ -247,23 +255,23 @@ def no_spm():
     used with pytest.mark.skipif decorator to skip tests
     that will fail if spm is not installed"""
 
-    if 'NIPYPE_NO_MATLAB' in os.environ or Info.version() is None:
+    if "NIPYPE_NO_MATLAB" in os.environ or Info.version() is None:
         return True
     else:
         return False
 
 
 class SPMCommandInputSpec(BaseInterfaceInputSpec):
-    matlab_cmd = traits.Str(desc='matlab command to use')
-    paths = InputMultiPath(Directory(), desc='Paths to add to matlabpath')
-    mfile = traits.Bool(True, desc='Run m-code using m-file', usedefault=True)
-    use_mcr = traits.Bool(desc='Run m-code using SPM MCR')
+    matlab_cmd = traits.Str(desc="matlab command to use")
+    paths = InputMultiPath(Directory(), desc="Paths to add to matlabpath")
+    mfile = traits.Bool(True, desc="Run m-code using m-file", usedefault=True)
+    use_mcr = traits.Bool(desc="Run m-code using SPM MCR")
     use_v8struct = traits.Bool(
         True,
-        min_ver='8',
+        min_ver="8",
         usedefault=True,
-        desc=('Generate SPM8 and higher '
-              'compatible jobs'))
+        desc=("Generate SPM8 and higher " "compatible jobs"),
+    )
 
 
 class SPMCommand(BaseInterface):
@@ -271,36 +279,38 @@ class SPMCommand(BaseInterface):
 
     WARNING: Pseudo prototype class, meant to be subclassed
     """
-    input_spec = SPMCommandInputSpec
-    _additional_metadata = ['field']
 
-    _jobtype = 'basetype'
-    _jobname = 'basename'
+    input_spec = SPMCommandInputSpec
+    _additional_metadata = ["field"]
+
+    _jobtype = "basetype"
+    _jobname = "basename"
 
     _matlab_cmd = None
     _paths = None
     _use_mcr = None
 
-    references_ = [{
-        'entry':
-        BibTeX(
-            "@book{FrackowiakFristonFrithDolanMazziotta1997,"
-            "author={R.S.J. Frackowiak, K.J. Friston, C.D. Frith, R.J. Dolan, and J.C. Mazziotta},"
-            "title={Human Brain Function},"
-            "publisher={Academic Press USA},"
-            "year={1997},"
-            "}"),
-        'description':
-        'The fundamental text on Statistical Parametric Mapping (SPM)',
-        # 'path': "nipype.interfaces.spm",
-        'tags': ['implementation'],
-    }]
+    references_ = [
+        {
+            "entry": BibTeX(
+                "@book{FrackowiakFristonFrithDolanMazziotta1997,"
+                "author={R.S.J. Frackowiak, K.J. Friston, C.D. Frith, R.J. Dolan, and J.C. Mazziotta},"
+                "title={Human Brain Function},"
+                "publisher={Academic Press USA},"
+                "year={1997},"
+                "}"
+            ),
+            "description": "The fundamental text on Statistical Parametric Mapping (SPM)",
+            # 'path': "nipype.interfaces.spm",
+            "tags": ["implementation"],
+        }
+    ]
 
     def __init__(self, **inputs):
         super(SPMCommand, self).__init__(**inputs)
         self.inputs.on_trait_change(
-            self._matlab_cmd_update,
-            ['matlab_cmd', 'mfile', 'paths', 'use_mcr'])
+            self._matlab_cmd_update, ["matlab_cmd", "mfile", "paths", "use_mcr"]
+        )
         self._find_mlab_cmd_defaults()
         self._check_mlab_inputs()
         self._matlab_cmd_update()
@@ -310,19 +320,16 @@ class SPMCommand(BaseInterface):
         cls._matlab_cmd = matlab_cmd
         cls._paths = paths
         cls._use_mcr = use_mcr
-        info_dict = Info.getinfo(
-            matlab_cmd=matlab_cmd,
-            paths=paths,
-            use_mcr=use_mcr)
+        info_dict = Info.getinfo(matlab_cmd=matlab_cmd, paths=paths, use_mcr=use_mcr)
 
     def _find_mlab_cmd_defaults(self):
         # check if the user has set environment variables to enforce
         # the standalone (MCR) version of SPM
-        if self._use_mcr or 'FORCE_SPMMCR' in os.environ:
+        if self._use_mcr or "FORCE_SPMMCR" in os.environ:
             self._use_mcr = True
             if self._matlab_cmd is None:
                 try:
-                    self._matlab_cmd = os.environ['SPMMCRCMD']
+                    self._matlab_cmd = os.environ["SPMMCRCMD"]
                 except KeyError:
                     pass
 
@@ -334,9 +341,11 @@ class SPMCommand(BaseInterface):
             matlab_cmd=self.inputs.matlab_cmd,
             mfile=self.inputs.mfile,
             paths=self.inputs.paths,
-            resource_monitor=False)
-        self.mlab.inputs.script_file = 'pyscript_%s.m' % \
-            self.__class__.__name__.split('.')[-1].lower()
+            resource_monitor=False,
+        )
+        self.mlab.inputs.script_file = (
+            "pyscript_%s.m" % self.__class__.__name__.split(".")[-1].lower()
+        )
         if isdefined(self.inputs.use_mcr) and self.inputs.use_mcr:
             self.mlab.inputs.nodesktop = Undefined
             self.mlab.inputs.nosplash = Undefined
@@ -349,10 +358,10 @@ class SPMCommand(BaseInterface):
         info_dict = Info.getinfo(
             matlab_cmd=self.inputs.matlab_cmd,
             paths=self.inputs.paths,
-            use_mcr=self.inputs.use_mcr)
+            use_mcr=self.inputs.use_mcr,
+        )
         if info_dict:
-            return '%s.%s' % (info_dict['name'].split('SPM')[-1],
-                              info_dict['release'])
+            return "%s.%s" % (info_dict["name"].split("SPM")[-1], info_dict["release"])
 
     @property
     def jobtype(self):
@@ -373,11 +382,12 @@ class SPMCommand(BaseInterface):
     def _run_interface(self, runtime):
         """Executes the SPM function using MATLAB."""
         self.mlab.inputs.script = self._make_matlab_command(
-            deepcopy(self._parse_inputs()))
+            deepcopy(self._parse_inputs())
+        )
         results = self.mlab.run()
         runtime.returncode = results.runtime.returncode
         if self.mlab.inputs.uses_mcr:
-            if 'Skipped' in results.runtime.stdout:
+            if "Skipped" in results.runtime.stdout:
                 self.raise_exception(runtime)
         runtime.stdout = results.runtime.stdout
         runtime.stderr = results.runtime.stderr
@@ -408,8 +418,8 @@ class SPMCommand(BaseInterface):
             if not isdefined(value):
                 continue
             field = spec.field
-            if '.' in field:
-                fields = field.split('.')
+            if "." in field:
+                fields = field.split(".")
                 dictref = spmdict
                 for f in fields[:-1]:
                     if f not in list(dictref.keys()):
@@ -447,9 +457,9 @@ class SPMCommand(BaseInterface):
 
             return [newdict]
         except TypeError:
-            print('Requires dict input')
+            print("Requires dict input")
 
-    def _generate_job(self, prefix='', contents=None):
+    def _generate_job(self, prefix="", contents=None):
         """Recursive function to generate spm job specification as a string
 
         Parameters
@@ -462,7 +472,7 @@ class SPMCommand(BaseInterface):
             matlab commands.
 
         """
-        jobstring = ''
+        jobstring = ""
         if contents is None:
             return jobstring
         if isinstance(contents, list):
@@ -486,22 +496,20 @@ class SPMCommand(BaseInterface):
                     jobstring += "{...\n"
                 for i, val in enumerate(contents):
                     if isinstance(val, np.ndarray):
-                        jobstring += self._generate_job(
-                            prefix=None, contents=val)
+                        jobstring += self._generate_job(prefix=None, contents=val)
                     elif isinstance(val, list):
                         items_format = []
                         for el in val:
                             items_format += [
-                                '{}' if not isinstance(el, (str, bytes)) else
-                                '\'{}\''
+                                "{}" if not isinstance(el, (str, bytes)) else "'{}'"
                             ]
-                        val_format = ', '.join(items_format).format
-                        jobstring += '[{}];...\n'.format(val_format(*val))
+                        val_format = ", ".join(items_format).format
+                        jobstring += "[{}];...\n".format(val_format(*val))
                     elif isinstance(val, (str, bytes)):
-                        jobstring += '\'{}\';...\n'.format(val)
+                        jobstring += "'{}';...\n".format(val)
                     else:
-                        jobstring += '%s;...\n' % str(val)
-                jobstring += '};\n'
+                        jobstring += "%s;...\n" % str(val)
+                jobstring += "};\n"
             else:
                 for i, val in enumerate(contents):
                     for field in val.dtype.fields:
@@ -552,36 +560,45 @@ class SPMCommand(BaseInterface):
         end\n
         """
         if self.mlab.inputs.mfile:
-            if (isdefined(self.inputs.use_v8struct)
-                    and self.inputs.use_v8struct):
-                mscript += self._generate_job('jobs{1}.spm.%s.%s' %
-                                              (self.jobtype,
-                                               self.jobname), contents[0])
+            if isdefined(self.inputs.use_v8struct) and self.inputs.use_v8struct:
+                mscript += self._generate_job(
+                    "jobs{1}.spm.%s.%s" % (self.jobtype, self.jobname), contents[0]
+                )
             else:
                 if self.jobname in [
-                        'st', 'smooth', 'preproc', 'preproc8', 'fmri_spec',
-                        'fmri_est', 'factorial_design', 'defs'
+                    "st",
+                    "smooth",
+                    "preproc",
+                    "preproc8",
+                    "fmri_spec",
+                    "fmri_est",
+                    "factorial_design",
+                    "defs",
                 ]:
                     # parentheses
-                    mscript += self._generate_job('jobs{1}.%s{1}.%s(1)' %
-                                                  (self.jobtype,
-                                                   self.jobname), contents[0])
+                    mscript += self._generate_job(
+                        "jobs{1}.%s{1}.%s(1)" % (self.jobtype, self.jobname),
+                        contents[0],
+                    )
                 else:
                     # curly brackets
-                    mscript += self._generate_job('jobs{1}.%s{1}.%s{1}' %
-                                                  (self.jobtype,
-                                                   self.jobname), contents[0])
+                    mscript += self._generate_job(
+                        "jobs{1}.%s{1}.%s{1}" % (self.jobtype, self.jobname),
+                        contents[0],
+                    )
         else:
             from scipy.io import savemat
+
             jobdef = {
-                'jobs': [{
-                    self.jobtype: [{
-                        self.jobname:
-                        self.reformat_dict_for_savemat(contents[0])
-                    }]
-                }]
+                "jobs": [
+                    {
+                        self.jobtype: [
+                            {self.jobname: self.reformat_dict_for_savemat(contents[0])}
+                        ]
+                    }
+                ]
             }
-            savemat(os.path.join(cwd, 'pyjobs_%s.mat' % self.jobname), jobdef)
+            savemat(os.path.join(cwd, "pyjobs_%s.mat" % self.jobname), jobdef)
             mscript += "load pyjobs_%s;\n\n" % self.jobname
         mscript += """
         spm_jobman(\'run\', jobs);\n
@@ -600,9 +617,15 @@ class SPMCommand(BaseInterface):
 class ImageFileSPM(ImageFile):
     """Defines a trait whose value must be a NIfTI file."""
 
-    def __init__(self, value=NoDefaultSpecified, exists=False, resolve=False, **metadata):
+    def __init__(
+        self, value=NoDefaultSpecified, exists=False, resolve=False, **metadata
+    ):
         """Create an ImageFileSPM trait."""
         super(ImageFileSPM, self).__init__(
-            value=value, exists=exists, types=['nifti1', 'nifti2'],
-            allow_compressed=False, resolve=resolve, **metadata)
-
+            value=value,
+            exists=exists,
+            types=["nifti1", "nifti2"],
+            allow_compressed=False,
+            resolve=resolve,
+            **metadata
+        )
